% general data and model information

% VAR model selected (1=OLS VAR, 2=BVAR, 3=mean-adjusted BVAR, 4=panel Bayesian VAR)
VARtype=1;
% data frequency (1=yearly, 2= quarterly, 3=monthly, 4=weekly, 5=daily, 6=undated)
frequency=1;
% sample start date; must be a string consistent with the date formats of the toolbox
startdate='';
% sample end date; must be a string consistent with the date formats of the toolbox
enddate='';
% endogenous variables; must be a single string, with variable names separated by a space
varendo='';
% exogenous variables, if any; must be a single string, with variable names separated by a space
varexo='';
% number of lags
lags=4;
% inclusion of a constant (1=yes, 0=no)
const=1;
% path to data; must be a single string
datapath='';
% pref: useless by itself, just here to avoid code to crash
pref=1;




% BVAR specific information: will be read only if VARtype=2

if VARtype==2
% selected prior
% 11=Minnesota (univariate AR), 12=Minnesota (diagonal VAR estimates), 13=Minnesota (full VAR estimates)
% 21=Normal-Wishart(S0 as univariate AR), 22=Normal-Wishart(S0 as identity)
% 31=Independent Normal-Wishart(S0 as univariate AR), 32=Independent Normal-Wishart(S0 as identity)
% 41=Normal-diffuse
% 51=Dummy observations
prior=11;
% hyperparameter: autoregressive coefficient
ar=0.8;
% hyperparameter: lambda1
lambda1=0.1;
% hyperparameter: lambda2
lambda2=0.5;
% hyperparameter: lambda3
lambda3=1;
% hyperparameter: lambda4
lambda4=100;
% hyperparameter: lambda5
lambda5=0.001;
% hyperparameter: lambda6
lambda6=1;
% hyperparameter: lambda7
lambda7=0.1;
% total number of iterations for the Gibbs sampler
It=2000;
% number of burn-in iterations for the Gibbs sampler
Bu=1000;
% hyperparameter optimisation by grid search (1=yes, 0=no)
hogs=0;
% block exogeneity (1=yes, 0=no)
bex=0;
% sum-of-coefficients application (1=yes, 0=no)
scoeff=0;
% dummy initial observation application (1=yes, 0=no)
iobs=0;





% Mean-adjusted BVAR specific information: will be read only if VARtype=3

elseif VARtype==3
% hyperparameter: autoregressive coefficient
ar=0.8;
% hyperparameter: lambda1
lambda1=0.1;
% hyperparameter: lambda2
lambda2=0.5;
% hyperparameter: lambda3
lambda3=1;
% hyperparameter: lambda4
lambda4=100;
% hyperparameter: lambda5
lambda5=0.001;
% total number of iterations for the Gibbs sampler
It=2000;
% number of burn-in iterations for the Gibbs sampler
Bu=1000;
% block exogeneity (1=yes, 0=no)
bex=0;





% panel Bayesian VAR specific information: will be read only if VARtype=4

elseif VARtype==4
% choice of panel model 
% 1=OLS mean group estimator, 2=pooled estimator
% 3=random effect (Zellner and Hong), 4=random effect (hierarchical)
% 5=static factor approach, 6=dynamic factor approach
panel=1;
% units; must be single sstring, with names separated by a space
unitnames='';
% total number of iterations for the Gibbs sampler
It=2000;
% number of burn-in iterations for the Gibbs sampler
Bu=1000;
% choice of retaining only one post burn iteration over 'pickf' iterations (1=yes, 0=no)
pick=0;
% frequency of iteration picking (e.g. pickf=20 implies that only 1 out of 20 iterations will be retained)
pickf=20;
% hyperparameter: autoregressive coefficient
ar=0.8;
% hyperparameter: lambda1
lambda1=0.1;
% hyperparameter: lambda2
lambda2=0.5;
% hyperparameter: lambda3
lambda3=1;
% hyperparameter: lambda4
lambda4=100;
% hyperparameter: s0
s0=0.001;
% hyperparameter: v0
v0=0.001;
% hyperparameter: alpha0
alpha0=1000;
% hyperparameter: delta0
delta0=1;
% hyperparameter: gama
gama=0.85;
% hyperparameter: a0
a0=1000;
% hyperparameter: b0
b0=1;
% hyperparameter: rho
rho=0.75;
% hyperparameter: psi
psi=0.1;

end





% Model options

% activate impulse response functions (1=yes, 0=no)
IRF=1;
% activate unconditional forecasts (1=yes, 0=no)
F=1;
% activate forecast error variance decomposition (1=yes, 0=no)
FEVD=0;
% activate historical decomposition (1=yes, 0=no)
HD=0;
% activate conditional forecasts (1=yes, 0=no)
CF=0;
% structural identification (1=none, 2=Choleski, 3=triangular factorisation, 4=sign restrictions)
IRFt=1;
% activate forecast evaluation (1=yes, 0=no)
Feval=1;
% type of conditional forecasts 
% 1=standard (all shocks), 2=standard (shock-specific)
% 3=tilting (median), 4=tilting (interval)
CFt=1;
% number of periods for impulse response functions
IRFperiods=20;
% start date for forecasts (has to be an in-sample date; otherwise, ignore and set Fendsmpl=1)
Fstartdate='';
% end date for forecasts
Fenddate='';
% start forecasts immediately after the final sample period (1=yes, 0=no)
% has to be set to 1 if start date for forecasts is not in-sample
Fendsmpl=1;
% confidence/credibility level for VAR coefficients
cband=0.95;
% confidence/credibility level for impusle response functions
IRFband=0.95;
% confidence/credibility level for forecasts
Fband=0.95;
% confidence/credibility level for forecast error variance decomposition
FEVDband=0.95;
% confidence/credibility level for historical decomposition
HDband=0.95;



